require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xrdcertificateconfiguration',
  dscmeta_resource_friendly_name: 'xRDCertificateConfiguration',
  dscmeta_resource_name: 'MSFT_xRDCertificateConfiguration',
  dscmeta_module_name: 'xRemoteDesktopSessionHost',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xRDCertificateConfiguration resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_connectionbroker: {
      type: 'String',
      desc: 'The connection broker that this certificate configuration is applied to.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_role: {
      type: "Enum['RDRedirector', 'RDPublishing', 'RDWebAccess', 'RDGateway']",
      desc: 'The role to apply this certificate configuration to.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the password used to decrypt the PFX file. The username is ignored.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_importpath: {
      type: 'String',
      desc: 'The certificate that should be used, should point to a PFX file on the filesystem.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
